Met dit systeem kunt u Nederlandstalige teksten doneren ten bate van het referentiecorpus hedendaags geschreven Nederlands (SoNaR).

Het doneren van tekst aan het SoNaR corpus wordt geregeld d.m.v. een overeenkomst tussen u (de donateur) en de Nederlandse TaalUnie, hier vertegenwoordigd door het projectteam van SoNaR.

Op de volgende pagina krijgt u de overeenkomst te lezen en kunt u uw teksten uploaden. Na donatie ontvangt u een e-mail met een overzicht van de door u gedoneerde teksten en een kopie van de overeenkomst.

Vul hieronder een willekeurige naam voor uw account in (zonder spaties en leestekens). Daarna kunt u starten met de donatie.